# Examples

This directory contains examples of how to use `routingblocks`:

* evrptw: An example implementation of an ALNS-based algorithm for the EVRPTW-PR problem.

## Running

Before running any of the examples, make sure that you've installed the example's requirements.
Then, to run any of the python examples:

```bash
python -m <example_name> -h
```

You can find further information in the respective example's README.